@@ -12,7 +12,7 @@ readDoublePorStream <- function(pstream) .Call("readDoublePorStream",pstream)
 readStringPorStream <- function(pstream) .Call("readStringPorStream",pstream)
 setTranslationPorStream <- function(pstream,translation) .Call("setTranslationPorStream",pstream,translation)
 readDataPorStream <- function(pstream,n,types) .Call("readDataPorStream",pstream,n,types)
-readSubsetPorStream <- function(pstream,types,use.vars,use.cases) .Call("readSubsetPorStream",pstream,types,use.vars,use.cases)
+readSlicePorStream <- function(pstream,types,use.vars,use.cases) .Call("readSlicePorStream",pstream,types,use.vars,use.cases)
 
 readPorStream <- function(pstream,n=1,start=NULL){
   if(missing(start))
